<?php
/* 
 * $Id: icl_core.settings.inc,v 1.11 2009/01/14 15:13:32 mihaigrigori Exp $
 * 
 * @file Page handler for admin settings callback
 */

module_load_include ( 'inc', 'icl_core', 'icl_core.webservices' );
module_load_include ( 'inc', 'icl_core', 'icl_core.constants' );


/**
 * This is a page callback for the ICanLocalize Core admin page
 *
 * @return array The system settings form.
 */
function icl_core_admin_settings() {
  $form = array ();
  $form ['icl_core_setup_instructions'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Getting started' ),
      '#value' => t ( '<div class="status"><b>Need help setting up ICanLocalize Translator? Visit the ') . '<a href="'. ICL_INSTALL_AND_SETUP_GUIDE . '">'. t ( 'getting started guide') . '</a></b></div>'
      );
  
  $form ['access_settings'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Access settings' ), 
      '#collapsible' => false );
  $form ['access_settings'] ['icl_core_website_id'] = array (
      '#type' => 'textfield', 
      '#title' => t ( 'Website ID' ), 
      '#default_value' => variable_get ( 'icl_core_website_id', '' ), 
      '#description' => t ( 'The website ID you received from ') . ICL_ICANLOCALIZE_LINK );
  $form ['access_settings'] ['icl_core_accesskey'] = array (
      '#type' => 'textfield', 
      '#title' => t ( 'Accesskey' ), 
      '#default_value' => variable_get ( 'icl_core_accesskey', '' ), 
      '#description' => t ( 'The accesskey you received from ') . ICL_ICANLOCALIZE_LINK );
  
  $form ['language_settings'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Languages' ), 
      '#collapsible' => FALSE);
  $form ['language_settings'] ['show_languages'] = array (
      '#type' => 'markup', 
      '#prefix' => '<div id="language-wrapper">', 
      '#suffix' => '</div>', 
      '#value' => _icl_core_settings_language_list () );
  $form ['language_settings'] ['retrieve_languages'] = array (
      '#type' => 'button', 
      '#value' => t ( 'Retrieve and refresh enabled translation languages' ), 
      '#ahah' => array (
          'path' => 'icl-core/retrieve-langs', 
          'wrapper' => 'language-wrapper', 
          'progress' => array (
              'type' => 'bar', 
              'message' => t ( 'Please wait...' ) ) ) );
  
  $options = array (
      ICL_CORE_RECEIVE_XMLRPC => t ( 'Translations will be posted back to this Drupal website via XML-RPC' ), 
      ICL_CORE_RECEIVE_POLL => t ( 'This Drupal installation will poll for translations' ) );
  $form ['icl_core_delivery'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Translation delivery' ), 
      '#collapsible' => FALSE);
  $form ['icl_core_delivery'] ['icl_core_receive_options'] = array (
      '#type' => 'radios', 
      '#title' => t ( 'Select the desired translation delivery method' ), 
      '#multiple' => FALSE, 
      '#options' => $options, 
      '#default_value' => variable_get ( 'icl_core_receive_options', ICL_CORE_RECEIVE_XMLRPC ), 
      '#description' => t ( 'Choose polling if your site is inaccessible from the Internet' ) );
  
  return system_settings_form ( $form );
}

/**
 * Validate the form and make sure we have a website id and accesskey
 *
 */

function icl_core_admin_settings_validate($form, &$form_state) {
  if($form_state['values']['icl_core_website_id'] == '') {
    form_set_error('', t('Please enter a website ID that you received from ') . ICL_ICANLOCALIZE_LINK );
  }
  elseif($form_state['values']['icl_core_accesskey'] == '') {
    form_set_error('', t('Please enter an accesskey that you received from ') . ICL_ICANLOCALIZE_LINK );
  }
}

/**
 * AHAH callback for ICanLocalize admin page
 * Returns the enabled languages for translation or an error message
 * when no languages are enabled.
 *
 */
function icl_core_retrieve_langs_js() {
  print drupal_to_js ( array (
      'status' => TRUE, 
      'data' => _icl_core_settings_language_list ( TRUE ) ) );
  exit ();
}

/*
 * Creates the available language list
 * 
 * @param $cache_clear TRUE to empty the internal caches, FALSE otherwise
 */
function _icl_core_settings_language_list($clear_cache = FALSE) {
  
  if ($clear_cache) {
    // we need record the current website id and accesskey and then
    // use the ones the user has entered on the settings page to get
    // the langauges setup on icanlocalize.
    
    $original_wid = variable_get ( 'icl_core_website_id', FALSE );    
    $original_accesskey = variable_get ( 'icl_core_accesskey', FALSE );
    
    // get the form state
    
    $form_state = array('storage' => NULL, 'submitted' => FALSE);
  
    $form = form_get_cache($_POST['form_build_id'], $form_state);
    $form['#post'] = $_POST;
  
    drupal_process_form('icl_core_admin_settings', $form, $form_state);
    
    // Use the website and accesskey the user has entered.
    
    variable_set('icl_core_website_id', $form_state['values']['icl_core_website_id']);
    variable_set('icl_core_accesskey', $form_state['values']['icl_core_accesskey']);
  }
  
  if($form_state['values']['icl_core_website_id'] != variable_get ( 'icl_core_website_id', '' ) || 
    $form_state['values']['icl_core_website_id'] != variable_get ( 'icl_core_website_id', '' ))
  {
        $clear_cache = TRUE;
        variable_set ( 'icl_core_languages', array() );
        $original_wid = variable_get ( 'icl_core_website_id', FALSE );    
        $original_accesskey = variable_get ( 'icl_core_accesskey', FALSE );
  }
  
  $languages = icl_core_available_languages ( $clear_cache );

  if ($clear_cache) {
    variable_set('icl_core_website_id', $original_wid);
    variable_set('icl_core_accesskey', $original_accesskey);
  }
  
  if (is_string ( $languages )) {
    if ($languages == '-1 cannot access') {
      $languages = t ('Cannot retrieve the languages from the ICanLocalize server. Please check the website ID and access key.');
    }
    return '<div class="error">' . $languages . '</div>';
  }
  
  if (empty ( $languages )) {
    $output = '<div class="error">' . t ( 'No languages have been defined. Please define at least one in your setup on ' ) . ICL_ICANLOCALIZE_LINK . '<br>' . t ('See ') . '<a href="' . ICL_INSTALL_AND_SETUP_GUIDE_LANGUAGES . '">' . t ('Install and setup guide') . '</a>' . t(' for details.') . '</div>';
  } else {
    $pairs = array ();
    foreach ( $languages as $from ) {
      foreach ( $from->targets as $to ) {
        $temp = t ( 'From %from to %to', array (
            '%from' => $from->name, 
            '%to' => $to->name ) );
        if (! $from->enabled || ! $to->enabled) {
          $temp .=  '<div class="error">'. t ('Disabled or not selected in Drupal.') . '</div>' . t ('Add appropriate languages on !locale settings page or enable them if they are already added.', array (
              '!locale' => l ( t ( 'Language' ), 'admin/settings/language/add', array (
                  'query' => 'destination=admin/settings/icl-core' ) ) ) ) ;
        }
        $pairs [] = $temp;
      }
    }
    $output = '<ul><li>' . implode ( '</li><li>', $pairs ) . '</li></ul>';
  }
  
  return $output;
}